/// <reference types="react" />
import * as PropTypes from "prop-types";
export declare enum ResizeType {
    Left = "resize-left",
    Right = "resize-right",
    Top = "resize-top",
    Bottom = "resize-bottom"
}
export declare enum AnchorType {
    Left = "anchor-left",
    Right = "anchor-right",
    Top = "anchor-top",
    Bottom = "anchor-bottom"
}
export declare const AnchorTypes: AnchorType[];
export declare const AnchorToResizeTypeMap: {
    "anchor-left": ResizeType;
    "anchor-right": ResizeType;
    "anchor-bottom": ResizeType;
    "anchor-top": ResizeType;
};
export declare enum CenterType {
    None = "none",
    Vertical = "vertical",
    HorizontalVertical = "horizontalVertical"
}
export interface IPublicProps {
    id?: string;
    className?: string;
    style?: React.CSSProperties;
    scrollable?: boolean;
    trackSize?: boolean;
    centerContent?: CenterType;
    as?: string;
    children?: React.ReactNode;
    debug?: boolean;
    zIndex?: number;
    onClick?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    onMouseDown?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    onMouseEnter?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
    onMouseLeave?: (event: React.MouseEvent<HTMLElement, MouseEvent>) => void;
}
export declare const publicProps: {
    id: PropTypes.Requireable<string>;
    className: PropTypes.Requireable<string>;
    style: PropTypes.Requireable<object>;
    scrollable: PropTypes.Requireable<boolean>;
    trackSize: PropTypes.Requireable<boolean>;
    centerContent: PropTypes.Requireable<CenterType>;
    as: PropTypes.Requireable<string>;
    debug: PropTypes.Requireable<boolean>;
    zIndex: PropTypes.Requireable<number>;
    onClick: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseDown: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseEnter: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseLeave: PropTypes.Requireable<(...args: any[]) => any>;
};
export interface IPrivateProps {
    anchorSize?: string | number;
    anchor?: AnchorType;
    resizable?: boolean;
    order?: number;
}
export declare const privateProps: {
    anchorSize: PropTypes.Requireable<import("react").ReactText>;
    anchor: PropTypes.Requireable<AnchorType>;
    resizable: PropTypes.Requireable<boolean>;
    order: PropTypes.Requireable<number>;
};
export interface IAnchoredProps {
    size: number | string;
    order?: number;
}
export declare const anchoredProps: {
    size: PropTypes.Validator<import("react").ReactText>;
    order: PropTypes.Requireable<number>;
};
export interface IResizableProps {
    handleSize?: number;
    overlayHandle?: boolean;
    minimumSize?: number;
    maximumSize?: number;
}
export declare const resizableProps: {
    handleSize: PropTypes.Requireable<number>;
    overlayHandle: PropTypes.Requireable<boolean>;
    minimumSize: PropTypes.Requireable<number>;
    maximumSize: PropTypes.Requireable<number>;
};
export interface IPositionedProps {
    left?: string | number;
    top?: string | number;
    right?: string | number;
    bottom?: string | number;
    width?: string | number;
    height?: string | number;
    resizable?: boolean;
}
export declare const positionedProps: {
    left: PropTypes.Requireable<import("react").ReactText>;
    top: PropTypes.Requireable<import("react").ReactText>;
    right: PropTypes.Requireable<import("react").ReactText>;
    bottom: PropTypes.Requireable<import("react").ReactText>;
    width: PropTypes.Requireable<import("react").ReactText>;
    height: PropTypes.Requireable<import("react").ReactText>;
    resizable: PropTypes.Requireable<boolean>;
};
export declare type AllProps = IPublicProps & IPrivateProps & IResizableProps & IPositionedProps;
export declare const allProps: {
    left: PropTypes.Requireable<import("react").ReactText>;
    top: PropTypes.Requireable<import("react").ReactText>;
    right: PropTypes.Requireable<import("react").ReactText>;
    bottom: PropTypes.Requireable<import("react").ReactText>;
    width: PropTypes.Requireable<import("react").ReactText>;
    height: PropTypes.Requireable<import("react").ReactText>;
    resizable: PropTypes.Requireable<boolean>;
    handleSize: PropTypes.Requireable<number>;
    overlayHandle: PropTypes.Requireable<boolean>;
    minimumSize: PropTypes.Requireable<number>;
    maximumSize: PropTypes.Requireable<number>;
    anchorSize: PropTypes.Requireable<import("react").ReactText>;
    anchor: PropTypes.Requireable<AnchorType>;
    order: PropTypes.Requireable<number>;
    id: PropTypes.Requireable<string>;
    className: PropTypes.Requireable<string>;
    style: PropTypes.Requireable<object>;
    scrollable: PropTypes.Requireable<boolean>;
    trackSize: PropTypes.Requireable<boolean>;
    centerContent: PropTypes.Requireable<CenterType>;
    as: PropTypes.Requireable<string>;
    debug: PropTypes.Requireable<boolean>;
    zIndex: PropTypes.Requireable<number>;
    onClick: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseDown: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseEnter: PropTypes.Requireable<(...args: any[]) => any>;
    onMouseLeave: PropTypes.Requireable<(...args: any[]) => any>;
};
export interface IState {
    id: string;
    currentWidth: number;
    currentHeight: number;
    adjustedSize: number;
    adjustedLeft: number;
    adjustedTop: number;
    spaceTakers: ISpaceTaker[];
    parsedSize?: number;
    left?: number | string;
    top?: number | string;
    right?: number | string;
    bottom?: number | string;
    width?: number | string;
    height?: number | string;
    debug: boolean;
}
export interface ISpaceContext {
    debug: boolean;
    zIndex: number;
    level: number;
    width: number;
    height: number;
    spaceTakers: ISpaceTaker[];
    registerSpaceTaker: (spaceTaker: ISpaceTaker) => void;
    removeSpaceTaker: (id: string) => void;
    updateSpaceTakerAdjustedSize: (id: string, adjustedSize: number) => void;
    updateDebug: (id: string, debug: boolean) => void;
    startDrag: (e: React.MouseEvent) => void;
}
export interface ISpaceTaker {
    id: string;
    order: number;
    zIndex: number;
    anchorType: AnchorType;
    size: number | string;
    adjustedSize: number;
}
export interface ISpaceInfo {
    width: number;
    height: number;
}
